# Single Elimination
This is a python package to manage the matches for a single elimination tournament.

For usage, see the test files.

Create an issue if you have any suggested features, changes, or documentation. Pull requests welcome.

Install with `pip install single_elimination`
